######################
 Command Line Examples
######################
The bohicalog module installs as a command line tool called bohicalog that is automatically added to the path.
The following is the output from the help.

.. command-output:: bohicalog --help


